<?php
/**
 * Plugin Name: YayMail Addon for B2B & Wholesale Suite
 * Plugin URI: https://yaycommerce.com/yaymail-woocommerce-email-customizer/
 * Description: Customize email templates for B2B & Wholesale Suite plugin
 * Version: 1.3
 * Author: YayCommerce
 * Author URI: https://yaycommerce.com
 * Text Domain: yaymail
 * WC requires at least: 3.0.0
 * WC tested up to: 5.4.1
 * Domain Path: /i18n/languages/
 */

namespace YayMailB2BWholesaleSuite;

defined( 'ABSPATH' ) || exit;
spl_autoload_register(
	function ( $class ) {
		$prefix   = __NAMESPACE__;
		$base_dir = __DIR__ . '/views';

		$len = strlen( $prefix );
		if ( strncmp( $prefix, $class, $len ) !== 0 ) {
			return;
		}

		$relative_class_name = substr( $class, $len );

		$file = $base_dir . str_replace( '\\', '/', $relative_class_name ) . '.php';

		if ( file_exists( $file ) ) {
			require $file;
		}
	}
);

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'YayMailB2BWholesaleSuite\\yaymail_addon_add_action_links' );
function yaymail_addon_add_action_links( $actions ) {

	if ( defined( 'YAYMAIL_PREFIX' ) ) {
		$links   = array(
			'<a href="' . admin_url( 'admin.php?page=yaymail-settings' ) . '" aria-label="' . esc_attr__( 'View WooCommerce Email Builder', 'yaymail' ) . '">' . esc_html__( 'Start Customizing', 'yaymail' ) . '</a>',
		);
		$actions = array_merge( $links, $actions );
	}
	return $actions;
}

add_filter( 'plugin_row_meta', 'YayMailB2BWholesaleSuite\\yaymail_addon_custom_plugin_row_meta', 10, 2 );
function yaymail_addon_custom_plugin_row_meta( $plugin_meta, $plugin_file ) {

	if ( strpos( $plugin_file, plugin_basename( __FILE__ ) ) !== false ) {
		$new_links = array(
			'docs'    => '<a href="https://yaycommerce.gitbook.io/yaymail/" aria-label="' . esc_attr__( 'View YayMail documentation', 'yaymail' ) . '">' . esc_html__( 'Docs', 'yaymail' ) . '</a>',
			'support' => '<a href="https://yaycommerce.com/support/" aria-label="' . esc_attr__( 'Visit community forums', 'yaymail' ) . '">' . esc_html__( 'Support', 'yaymail' ) . '</a>',
		);

		$plugin_meta = array_merge( $plugin_meta, $new_links );
	}

	return $plugin_meta;
}
add_action( 'after_plugin_row_' . plugin_basename( __FILE__ ), 'YayMailB2BWholesaleSuite\\yaymail_addon_add_notification_after_plugin_row', 10, 2 );

function yaymail_addon_add_notification_after_plugin_row( $plugin_file, $plugin_data ) {

	if ( ! defined( 'YAYMAIL_PREFIX' ) ) {
		$wp_list_table = _get_list_table( 'WP_MS_Themes_List_Table' );
		?>
		<script>
		var plugin_row_element = document.querySelector('tr[data-plugin="<?php echo esc_js( plugin_basename( __FILE__ ) ); ?>"]');
		plugin_row_element.classList.add('update');
		</script>
		<?php
		echo '<tr class="plugin-update-tr' . ( is_plugin_active( $plugin_file ) ? ' active' : '' ) . '"><td colspan="' . esc_attr( $wp_list_table->get_column_count() ) . '" class="plugin-update colspanchange" >';
		echo '<div class="notice inline notice-warning notice-alt"><p>';
		echo esc_html__( 'To use this addon, you need to install and activate YayMail plugin. Get ', 'yaymail' ) . '<a href="' . esc_url( 'https://wordpress.org/plugins/yaymail/' ) . '">' . esc_html__( 'YayMail Free', 'yaymail' ) . '</a> or <a href="' . esc_url( 'https://yaycommerce.com/yaymail-woocommerce-email-customizer/' ) . '">' . esc_html__( 'YayMail Pro', 'yaymail' ) . '</a>.
					</p>
				</div>
			</td>
			</tr>';
	}

}

add_filter(
	'yaymail_plugins',
	function( $plugins ) {
		if ( class_exists( 'B2bwhs' ) ) {
			$plugins[] = array(
				'plugin_name'      => 'B2BWholesaleSuite', // --> CHANGE HERE => name of plugin (maybe name of the class)
				'addon_components' => array(), // CHANGE HERE => main-name required
				'template_name'    => array(
					'b2bwhs_new_customer_email',
					'b2bwhs_new_customer_requires_approval_email',
					'b2bwhs_new_message_email',
					'b2bwhs_new_quote_email',
					'b2bwhs_your_account_approved_email',
				),
			);
		}
		return $plugins;
	},
	10,
	1
);

// Action create template default
add_filter( 'YaymailNewTempalteDefault', 'YayMailB2BWholesaleSuite\\yaymail_new_template_default', 100, 3 );
function yaymail_new_template_default($array, $key, $value ) {
	if ( class_exists( 'B2bwhs' ) ) {
		if ( 'B2bwhs_New_Message_Email' == $key ) {
			$getHeading               = $value->heading;
			$B2bwhs_New_Message_Email = templateDefault\NewMessageEmail::getTemplates( $value->id, $getHeading );
			return $B2bwhs_New_Message_Email;
		} elseif ( $key === 'B2bwhs_Your_Account_Approved_Email' ) {
			$getHeading                         = $value->heading;
			$B2bwhs_Your_Account_Approved_Email = templateDefault\YourAccountApprovedEmail::getTemplates( $value->id, $getHeading );
			return $B2bwhs_Your_Account_Approved_Email;
		} elseif ( $key === 'B2bwhs_New_Customer_Requires_Approval_Email' ) {
			$getHeading                                  = $value->heading;
			$B2bwhs_New_Customer_Requires_Approval_Email = templateDefault\NewCustomerRequiresApprovalEmail::getTemplates( $value->id, $getHeading );
			return $B2bwhs_New_Customer_Requires_Approval_Email;
		} elseif ( $key === 'B2bwhs_New_Customer_Email' ) {
			$getHeading                = $value->heading;
			$B2bwhs_New_Customer_Email = templateDefault\NewCustomerEmail::getTemplates( $value->id, $getHeading );
			return $B2bwhs_New_Customer_Email;
		} elseif ( $key === 'B2bwhs_New_Quote_Email' ) {
			$getHeading             = $value->heading;
			$B2bwhs_New_Quote_Email = templateDefault\NewQuoteEmail::getTemplates( $value->id, $getHeading );
			return $B2bwhs_New_Quote_Email;
		}

		return $array;
	}
}

/*
Action to defined shortcode
$arrData[0] : $custom_shortcode
$arrData[1] : $args
$arrData[2] : $templateName
*/

add_action(
	'yaymail_addon_defined_shorcode',
	function( $arrData ) {
		$templateWooSubscription = array(
			'b2bwhs_new_customer_email',
			'b2bwhs_new_customer_requires_approval_email',
			'b2bwhs_new_message_email',
			'b2bwhs_new_quote_email',
			'b2bwhs_your_account_approved_email',
		);
		if ( in_array( $arrData[2], $templateWooSubscription ) ) {
			$arrData[0]->setOrderId( 0, isset( $arrData[1]['sent_to_admin'] ) ? $arrData[1]['sent_to_admin'] : false, $arrData[1] );
			$arrData[0]->shortCodesOrderDefined( isset( $arrData[1]['sent_to_admin'] ) ? $arrData[1]['sent_to_admin'] : false, $arrData[1] );
		}
	}
);

// Filter to defined template
add_filter(
	'yaymail_addon_defined_template',
	function($result, $template ) {
		$templateWooSubscription = array(
			'b2bwhs_new_customer_email',
			'b2bwhs_new_customer_requires_approval_email',
			'b2bwhs_new_message_email',
			'b2bwhs_new_quote_email',
			'b2bwhs_your_account_approved_email',
		);
		if ( in_array( $template, $templateWooSubscription ) ) {
			return true;
		}
		return $result;
	},10,2
);

// CHANGE HERE
// Filter to add template to Vuex
add_filter(
	'yaymail_addon_templates',
	function( $addon_templates, $order, $post_id ) {
		$components = apply_filters( 'yaymail_plugins', array() );
		$position   = '';
		foreach ( $components as $key => $component ) {
			if ( $component['plugin_name'] === 'B2BWholesaleSuite' ) {
				$position = $key;
				break;
			}
		}
		foreach ( $components[$position]['addon_components'] as $key => $component ) {
			ob_start();
			do_action( 'YaymailAddon' . $component . 'Vue', $order, $post_id );
			$html = ob_get_contents();
			ob_end_clean();
			$addon_templates['b2bwholesale_suite'] = array_merge( isset( $addon_templates['b2bwholesale_suite'] ) ? $addon_templates['b2bwholesale_suite'] : array(), array( $component . 'Vue' => $html ) );
		}
		return $addon_templates;
	},
	10,
	3
);

/** SHORTCODE WILL DO HERE */
// Display shortcode in core
add_filter(
	'yaymail_list_shortcodes',
	function( $shortcode_list ) {
		$shortcode_list[] = array(
			'plugin' => 'B2B & Wholesale Suite',
			'shortcode' => array(
				['[yaymail_addon_b2bwholesale_suite_review_user]', 'Review User'],
				['[yaymail_addon_b2bwholesale_suite_new_quote_name]', 'New Quote Name'],
				['[yaymail_addon_b2bwholesale_suite_new_quote_email]', 'New Quote Email'],
				['[yaymail_addon_b2bwholesale_suite_new_quote_phone]', 'New Quote Phone'],
				['[yaymail_addon_b2bwholesale_suite_new_quote_message]', 'New Quote Message'],
				['[yaymail_addon_b2bwholesale_suite_new_quote_item_cart]', 'New Quote Item Cart'],
			)
		);

		return $shortcode_list;
	},
	10,
	1
);
// Add new shortcode to shortcodes list
add_filter(
	'yaymail_shortcodes',
	function( $shortcode_list ) {
		if ( class_exists( 'B2bwhs' ) ) {
			$shortcode_list[] = 'yaymail_addon_b2bwholesale_suite_review_user';
			$shortcode_list[] = 'yaymail_addon_b2bwholesale_suite_new_quote_name';
			$shortcode_list[] = 'yaymail_addon_b2bwholesale_suite_new_quote_email';
			$shortcode_list[] = 'yaymail_addon_b2bwholesale_suite_new_quote_phone';
			$shortcode_list[] = 'yaymail_addon_b2bwholesale_suite_new_quote_message';
			$shortcode_list[] = 'yaymail_addon_b2bwholesale_suite_new_quote_item_cart';

			// template message
			$shortcode_list[] = 'yaymail_addon_b2bwholesale_suite_new_quote_user';
		}

		return $shortcode_list;
	},
	10,
	1
);

// Create shortcode
add_filter(
	'yaymail_do_shortcode',
	function( $shortcode_list, $yaymail_informations, $args = array() ) {
		if ( class_exists( 'B2bwhs' ) ) {
			$shortcode_list['[yaymail_addon_b2bwholesale_suite_review_user]']         = yaymailAddonB2BWholesaleSuiteReviewUser( $yaymail_informations, $args );
			$shortcode_list['[yaymail_addon_b2bwholesale_suite_new_quote_name]']      = yaymailAddonB2BWholesaleSuiteNewQuoteName( $yaymail_informations, $args );
			$shortcode_list['[yaymail_addon_b2bwholesale_suite_new_quote_email]']     = yaymailAddonB2BWholesaleSuiteNewQuoteEmail( $yaymail_informations, $args );
			$shortcode_list['[yaymail_addon_b2bwholesale_suite_new_quote_phone]']     = yaymailAddonB2BWholesaleSuiteNewQuotePhone( $yaymail_informations, $args );
			$shortcode_list['[yaymail_addon_b2bwholesale_suite_new_quote_message]']   = yaymailAddonB2BWholesaleSuiteNewQuoteMessage( $yaymail_informations, $args );
			$shortcode_list['[yaymail_addon_b2bwholesale_suite_new_quote_item_cart]'] = yaymailAddonB2BWholesaleSuiteNewQuoteItemCart( $yaymail_informations, $args );

			// template message
			$shortcode_list['[yaymail_addon_b2bwholesale_suite_new_quote_user]'] = yaymailAddonB2BWholesaleSuiteNewQuoteUser( $yaymail_informations, $args );
		}

		return $shortcode_list;
	},
	10,
	3
);

function yaymailAddonB2BWholesaleSuiteReviewUser( $yaymail_informations, $args = array() ) {
	ob_start();
	include plugin_dir_path( __FILE__ ) . '/views/template/yaymailAddonB2BWholesaleSuiteReviewUser.php';
	$html = ob_get_contents();
	ob_end_clean();
	return $html;
}

function yaymailAddonB2BWholesaleSuiteNewQuoteName( $yaymail_informations, $args = array() ) {
	if ( isset( $_POST['name'] ) && isset( $args['email'] ) ) {
		$name        = sanitize_text_field( $_POST['name'] );
		$messagecart = esc_html__( 'Name: ', 'b2b-wholesale-suite' ) . $name . ' <br />';
		return $messagecart;
	}

	if ( ! isset( $args['email'] ) ) {
		return esc_html__( 'Name: ', 'b2b-wholesale-suite' ) . 'YayMail' . ' <br />';
	}
}

function yaymailAddonB2BWholesaleSuiteNewQuoteEmail( $yaymail_informations, $args = array() ) {
	if ( isset( $_POST['email'] ) && isset( $args['email'] ) ) {
		$email       = sanitize_text_field( $_POST['email'] );
		$messagecart = esc_html__( 'Email: ', 'b2b-wholesale-suite' ) . $email . ' <br />';
		return $messagecart;
	}

	if ( ! isset( $args['email'] ) ) {
		return esc_html__( 'Email: ', 'b2b-wholesale-suite' ) . 'yaymail@gmail.com' . ' <br />';
	}
}

function yaymailAddonB2BWholesaleSuiteNewQuotePhone( $yaymail_informations, $args = array() ) {
	if ( isset( $_POST['phone'] ) && isset( $args['email'] ) ) {
		$phone       = sanitize_text_field( $_POST['phone'] );
		$messagecart = esc_html__( 'Phone: ', 'b2b-wholesale-suite' ) . $phone . ' <br />';
		return $messagecart;
	}
	if ( ! isset( $args['email'] ) ) {
		return esc_html__( 'Phone: ', 'b2b-wholesale-suite' ) . '0901234567' . ' <br />';
	}
}

function yaymailAddonB2BWholesaleSuiteNewQuoteMessage( $yaymail_informations, $args = array() ) {
	if ( isset( $_POST['message'] ) && isset( $args['email'] ) ) {
		$message     = sanitize_text_field( $_POST['message'] );
		$messagecart = esc_html__( 'Message: ', 'b2b-wholesale-suite' ) . $message . ' <br />';
		return $messagecart;
	} elseif ( isset( $args['email'] ) && isset( $args['message'] ) ) {
		$message     = sanitize_textarea_field( $args['message'] );
		$messagecart = esc_html__( 'Message: ', 'b2b-wholesale-suite' ) . $message . ' <br />';
		return $messagecart;
	}
	return esc_html__( 'Message: ', 'b2b-wholesale-suite' ) . 'YayMail message' . ' <br />';
}

function yaymailAddonB2BWholesaleSuiteNewQuoteItemCart( $yaymail_informations, $args = array() ) {
	if ( isset( $args['email'] ) && 'b2bwhs_new_quote_email' === $args['email']->id ) {
		$messagecart = '';
		$items       = WC()->cart->get_cart();
		foreach ( $items as $item => $values ) {
			$_product     = wc_get_product( $values['data']->get_id() );
			$messagecart .= '<b>' . $_product->get_name() . '</b>  <br> ' . esc_html__( 'Quantity: ', 'b2b-wholesale-suite' ) . $values['quantity'] . '<br>';
		}
		return $messagecart;
	}

	if ( ! isset( $args['email'] ) ) {
		return '<b>' . 'YayMail' . '</b>  <br> ' . esc_html__( 'Quantity: ', 'b2b-wholesale-suite' ) . '1' . '<br>';
	}
}


function yaymailAddonB2BWholesaleSuiteNewQuoteUser( $yaymail_informations, $args = array() ) {
	if ( isset( $_POST['user_ID'] ) && isset( $args['email'] ) ) {
		$userid      = sanitize_text_field( $_POST['user_ID'] );
		$user_loggin = get_user_by( 'id', $userid )->user_login;
		$UserName    = esc_html__( 'User: ', 'b2b-wholesale-suite' ) . $user_loggin . ' <br />';
		return $UserName;
	}
	if ( ! isset( $args['email'] ) ) {
		return esc_html__( 'User: ', 'b2b-wholesale-suite' ) . 'YayMail' . ' <br />';
	}

}

/** END SHORTCODE */





